@@ -173,7 +173,7 @@ use common::sense;
 use base 'Exporter';
 
 BEGIN {
-   our $VERSION = 4.5;
+   our $VERSION = 4.51;
 
    our @AIO_REQ = qw(aio_sendfile aio_seek aio_read aio_write aio_open aio_close
                      aio_stat aio_lstat aio_unlink aio_rmdir aio_readdir aio_readdirx
@@ -563,6 +563,9 @@ C<S_IFMT>, C<S_IFIFO>, C<S_IFCHR>, C<S_IFBLK>, C<S_IFLNK>, C<S_IFREG>,
 C<S_IFDIR>, C<S_IFWHT>, C<S_IFSOCK>, C<IO::AIO::major $dev_t>,
 C<IO::AIO::minor $dev_t>, C<IO::AIO::makedev $major, $minor>.
 
+To access higher resolution stat timestamps, see L<SUBSECOND STAT TIME
+ACCESS>.
+
 Example: Print the length of F</etc/passwd>:
 
    aio_stat "/etc/passwd", sub {
@@ -2012,6 +2015,76 @@ but not yet processed by poll_cb).
 
 =back
 
+=head3 SUBSECOND STAT TIME ACCESS
+
+Both C<aio_stat>/C<aio_lstat> and perl's C<stat>/C<lstat> functions can
+generally find access/modification and change times with subsecond time
+accuracy of the system supports it, but perl's built-in functions only
+return the integer part.
+
+The following functions return the timestamps of the most recent
+stat with subsecond precision on most systems and work both after
+C<aio_stat>/C<aio_lstat> and perl's C<stat>/C<lstat> calls. Their return
+value is only meaningful after a successful C<stat>/C<lstat> call, or
+during/after a successful C<aio_stat>/C<aio_lstat> callback.
+
+This is similar to the L<Time::HiRes> C<stat> functions, but can return
+full resolution without rounding and work with standard perl C<stat>,
+alleviating the need to call the special C<Time::HiRes> functions, which
+do not act like their perl counterparts.
+
+On operating systems or file systems where subsecond time resolution is
+not supported or could not be detected, a fractional part of C<0> is
+returned, so it is always safe to call these functions.
+
+=over 4
+
+=item $seconds = IO::AIO::st_atime, IO::AIO::st_mtime, IO::AIO::st_ctime
+
+Return the access, modication or change time, respectively, including
+fractional part. Due to the limited precision of floating point, the
+accuracy on most platforms is only a bit better than milliseconds for
+times around now - see the I<nsec> function family, below, for full
+accuracy.
+
+=item ($atime, $mtime, $ctime, ...) = IO::AIO::st_xtime
+
+Returns access, modification and change time all in one go, and maybe more
+times in the future version.
+
+=item $nanoseconds = IO::AIO::st_atimensec, IO::AIO::st_mtimensec, IO::AIO::st_ctimensec
+
+Return the fractional access, modifcation or change time, in nanoseconds,
+as an integer in the range C<0> to C<999999999>.
+
+=item ($atime, $mtime, $ctime, ...) = IO::AIO::st_xtimensec
+
+Like the functions above, but returns all three times in one go (and maybe
+more in future versions).
+
+=back
+
+Example: print the high resolution modification time of F</etc>, using
+C<stat>, and C<IO::AIO::aio_stat>.
+
+   if (stat "/etc") {
+      printf "stat(/etc) mtime: %f\n", IO::AIO::st_mtime;
+   }
+
+   IO::AIO::aio_stat "/etc", sub {
+      $_[0]
+         and return;
+
+      printf "aio_stat(/etc) mtime: %d.%09d\n", (stat _)[9], IO::AIO::st_mtimensec;
+   };
+
+   IO::AIO::flush;
+
+Output of the awbove on my system, showing reduced and full accuracy:
+
+   stat(/etc) mtime: 1534043702.020808
+   aio_stat(/etc) mtime: 1534043702.020807792
+
 =head3 MISCELLANEOUS FUNCTIONS
 
 IO::AIO implements some functions that are useful when you want to use
